@@ -13,6 +13,15 @@ import os
 import sys
 
 import psutil
+import py
+
+try:
+    import salt.utils.dictupdate
+except ImportError:  # pragma: no cover
+    # We need salt to test salt with saltfactories, and, when pytest is rewriting modules for proper assertion
+    # reporting, we still haven't had a chance to inject the salt path into sys.modules, so we'll hit this
+    # import error, but its safe to pass
+    pass
 
 import saltfactories.utils.processes.helpers
 import saltfactories.utils.processes.salts as salt_factories
@@ -68,7 +77,7 @@ class SaltFactoriesManager(object):
             inject_coverage (bool):
                 Inject code-coverage related code in the generated CLI scripts
             inject_sitecustomize (bool):
-                Inject code in the generated CLI scripts in order for our `sitecustumise.py` to be loaded by
+                Inject code in the generated CLI scripts in order for our `sitecustomise.py` to be loaded by
                 subprocesses.
             cwd (str):
                 The path to the current working directory
@@ -178,7 +187,7 @@ class SaltFactoriesManager(object):
         if "engines_dirs" not in config:
             config["engines_dirs"] = []
         config["engines_dirs"].insert(0, SaltFactoriesManager.get_salt_engines_path())
-        config["user"] = SaltFactoriesManager.get_running_username()
+        config.setdefault("user", SaltFactoriesManager.get_running_username())
         if "log_forwarding_consumer" not in config:
             # Still using old logging, let's add our custom log handler
             if "log_handlers_dirs" not in config:
@@ -198,45 +207,229 @@ class SaltFactoriesManager(object):
         log_config["port"] = self.log_server_port
         log_config["level"] = self.log_server_level
 
-    def configure_minion(self, request, minion_id, master_id=None):
+    def configure_master(
+        self,
+        request,
+        master_id,
+        order_masters=False,
+        master_of_masters_id=None,
+        config_defaults=None,
+        config_overrides=None,
+    ):
+        """
+        Configure a salt-master
+
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            master_id(str):
+                The master ID
+            order_masters(bool):
+                Boolean flag to set if this master is going to control other masters(ie, master of masters), like,
+                for example, in a :ref:`Syndic <salt:syndic>` topology scenario
+            master_of_masters_id(str):
+                The master of masters ID, like, for example, in a :ref:`Syndic <salt:syndic>` topology scenario
+            config_defaults(dict):
+                A dictionary of default configuration to use when configuring the master
+            config_overrides(dict):
+                A dictionary of configuration overrides to use when configuring the master
+
+        Returns:
+            dict: The master configuring dictionary
+        """
+        if master_id in self.cache["configs"]["masters"]:
+            return self.cache["configs"]["masters"][master_id]
+
+        root_dir = self._get_root_dir_for_daemon(master_id, config_defaults=config_defaults)
+
+        _config_defaults = self.pytestconfig.hook.pytest_saltfactories_master_configuration_defaults(
+            request=request,
+            factories_manager=self,
+            root_dir=root_dir,
+            master_id=master_id,
+            order_masters=order_masters,
+        )
+        if config_defaults:
+            if _config_defaults:
+                salt.utils.dictupdate.update(_config_defaults, config_defaults)
+            else:
+                _config_defaults = config_defaults.copy()
+
+        _config_overrides = self.pytestconfig.hook.pytest_saltfactories_master_configuration_overrides(
+            request=request,
+            factories_manager=self,
+            root_dir=root_dir,
+            master_id=master_id,
+            config_defaults=_config_defaults,
+            order_masters=order_masters,
+        )
+        if config_overrides:
+            if _config_overrides:
+                salt.utils.dictupdate.update(_config_overrides, config_overrides)
+            else:
+                _config_overrides = config_overrides.copy()
+
+        if master_of_masters_id:
+            master_of_masters_config = self.cache["configs"]["masters"].get(master_of_masters_id)
+            if master_of_masters_config is None:
+                raise RuntimeError("No config found for {}".format(master_of_masters_id))
+            if config_overrides is None:
+                config_overrides = {}
+            config_overrides["syndic_master"] = master_of_masters_config["interface"]
+            config_overrides["syndic_master_port"] = master_of_masters_config["ret_port"]
+
+        master_config = master.MasterFactory.default_config(
+            root_dir,
+            master_id=master_id,
+            config_defaults=_config_defaults,
+            config_overrides=_config_overrides,
+            order_masters=order_masters,
+        )
+        self.final_master_config_tweaks(master_config)
+        master_config = self.pytestconfig.hook.pytest_saltfactories_master_write_configuration(
+            request=request, master_config=master_config
+        )
+        self.pytestconfig.hook.pytest_saltfactories_master_verify_configuration(
+            request=request,
+            master_config=master_config,
+            username=SaltFactoriesManager.get_running_username(),
+        )
+        self.cache["configs"]["masters"][master_id] = master_config
+        request.addfinalizer(lambda: self.cache["configs"]["masters"].pop(master_id))
+        return master_config
+
+    def spawn_master(
+        self,
+        request,
+        master_id,
+        order_masters=False,
+        master_of_masters_id=None,
+        config_defaults=None,
+        config_overrides=None,
+        max_start_attempts=3,
+        **extra_daemon_class_kwargs
+    ):
+        """
+        Spawn a salt-master
+
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            master_id(str):
+                The master ID
+            order_masters(bool):
+                Boolean flag to set if this master is going to control other masters(ie, master of masters), like,
+                for example, in a :ref:`Syndic <salt:syndic>` topology scenario
+            master_of_masters_id(str):
+                The master of masters ID, like, for example, in a :ref:`Syndic <salt:syndic>` topology scenario
+            config_defaults(dict):
+                A dictionary of default configuration to use when configuring the master
+            config_overrides(dict):
+                A dictionary of configuration overrides to use when configuring the master
+            max_start_attempts(int):
+                How many attempts should be made to start the master in case of failure to validate that its running
+            extra_daemon_class_kwargs(dict):
+                Extra keyword arguments to pass to :py:class:`~saltfactories.utils.processes.salts.SaltMaster`
+
+        Returns:
+            :py:class:`~saltfactories.utils.processes.salts.SaltMaster`:
+                The master process class instance
+        """
+        if master_id in self.cache["masters"]:
+            raise RuntimeError("A master by the ID of '{}' was already spawned".format(master_id))
+
+        master_config = self.cache["configs"]["masters"].get(master_id)
+        if master_config is None:
+            master_config = self.configure_master(
+                request,
+                master_id,
+                order_masters=order_masters,
+                master_of_masters_id=master_of_masters_id,
+                config_defaults=config_defaults,
+                config_overrides=config_overrides,
+            )
+
+        return self._start_daemon(
+            request,
+            "salt-master",
+            master_config,
+            salt_factories.SaltMaster,
+            "masters",
+            master_id,
+            max_start_attempts=max_start_attempts,
+            **extra_daemon_class_kwargs
+        )
+
+    def configure_minion(
+        self, request, minion_id, master_id=None, config_defaults=None, config_overrides=None
+    ):
         """
         Configure a salt-minion
+
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            minion_id(str):
+                The minion ID
+            master_id(str):
+                The master ID this minion will connect to.
+            config_defaults(dict):
+                A dictionary of default configuration to use when configuring the minion
+            config_overrides(dict):
+                A dictionary of configuration overrides to use when configuring the minion
+
+        Returns:
+            dict: The minion configuration dictionary
+
         """
         if minion_id in self.cache["configs"]["minions"]:
             return self.cache["configs"]["minions"][minion_id]
 
-        root_dir = self._get_root_dir_for_daemon(minion_id)
+        root_dir = self._get_root_dir_for_daemon(minion_id, config_defaults=config_defaults)
 
         master_port = None
         if master_id is not None:
             master_config = self.cache["configs"]["masters"][master_id]
             master_port = master_config.get("ret_port")
-        default_options = self.pytestconfig.hook.pytest_saltfactories_generate_default_minion_configuration(
+
+        _config_defaults = self.pytestconfig.hook.pytest_saltfactories_minion_configuration_defaults(
             request=request,
             factories_manager=self,
             root_dir=root_dir,
             minion_id=minion_id,
             master_port=master_port,
         )
-        config_overrides = self.pytestconfig.hook.pytest_saltfactories_minion_configuration_overrides(
+        if config_defaults:
+            if _config_defaults:
+                salt.utils.dictupdate.update(_config_defaults, config_defaults)
+            else:
+                _config_defaults = config_defaults.copy()
+
+        _config_overrides = self.pytestconfig.hook.pytest_saltfactories_minion_configuration_overrides(
             request=request,
             factories_manager=self,
             root_dir=root_dir,
             minion_id=minion_id,
-            default_options=default_options,
+            config_defaults=_config_defaults,
         )
+        if config_overrides:
+            if _config_overrides:
+                salt.utils.dictupdate.update(_config_overrides, config_overrides)
+            else:
+                _config_overrides = config_overrides.copy()
+
         minion_config = minion.MinionFactory.default_config(
             root_dir,
             minion_id=minion_id,
-            default_options=default_options,
-            config_overrides=config_overrides,
+            config_defaults=_config_defaults,
+            config_overrides=_config_overrides,
             master_port=master_port,
         )
         self.final_minion_config_tweaks(minion_config)
-        minion_config = self.pytestconfig.hook.pytest_saltfactories_write_minion_configuration(
+        minion_config = self.pytestconfig.hook.pytest_saltfactories_minion_write_configuration(
             request=request, minion_config=minion_config
         )
-        self.pytestconfig.hook.pytest_saltfactories_verify_minion_configuration(
+        self.pytestconfig.hook.pytest_saltfactories_minion_verify_configuration(
             request=request,
             minion_config=minion_config,
             username=SaltFactoriesManager.get_running_username(),
@@ -252,104 +445,97 @@ class SaltFactoriesManager(object):
         request.addfinalizer(lambda: self.cache["configs"]["minions"].pop(minion_id))
         return minion_config
 
-    def spawn_minion(self, request, minion_id, master_id=None):
+    def spawn_minion(
+        self,
+        request,
+        minion_id,
+        master_id=None,
+        config_defaults=None,
+        config_overrides=None,
+        max_start_attempts=3,
+        **extra_daemon_class_kwargs
+    ):
         """
         Spawn a salt-minion
+
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            minion_id(str):
+                The minion ID
+            master_id(str):
+                The master ID this minion will connect to.
+            config_defaults(dict):
+                A dictionary of default configuration to use when configuring the minion
+            config_overrides(dict):
+                A dictionary of configuration overrides to use when configuring the minion
+            max_start_attempts(int):
+                How many attempts should be made to start the minion in case of failure to validate that its running
+            extra_daemon_class_kwargs(dict):
+                Extra keyword arguments to pass to :py:class:`~saltfactories.utils.processes.salts.SaltMinion`
+
+        Returns:
+            :py:class:`~saltfactories.utils.processes.salts.SaltMinion`:
+                The minion process class instance
         """
         if minion_id in self.cache["minions"]:
             raise RuntimeError("A minion by the ID of '{}' was already spawned".format(minion_id))
 
         minion_config = self.cache["configs"]["minions"].get(minion_id)
         if minion_config is None:
-            minion_config = self.configure_minion(request, minion_id, master_id=master_id)
-
-        return self._start_daemon(
-            request, "salt-minion", minion_config, salt_factories.SaltMinion, "minions", minion_id
-        )
-
-    def configure_master(self, request, master_id, order_masters=False, master_of_masters_id=None):
-        """
-        Configure a salt-master
-        """
-        if master_id in self.cache["configs"]["masters"]:
-            return self.cache["configs"]["masters"][master_id]
-
-        root_dir = self._get_root_dir_for_daemon(master_id)
-
-        default_options = self.pytestconfig.hook.pytest_saltfactories_generate_default_master_configuration(
-            request=request,
-            factories_manager=self,
-            root_dir=root_dir,
-            master_id=master_id,
-            order_masters=order_masters,
-        )
-        config_overrides = self.pytestconfig.hook.pytest_saltfactories_master_configuration_overrides(
-            request=request,
-            factories_manager=self,
-            root_dir=root_dir,
-            master_id=master_id,
-            default_options=default_options,
-            order_masters=order_masters,
-        )
-
-        if master_of_masters_id:
-            master_of_masters_config = self.cache["configs"]["masters"].get(master_of_masters_id)
-            if master_of_masters_config is None:
-                raise RuntimeError("No config found for {}".format(master_of_masters_id))
-            if config_overrides is None:
-                config_overrides = {}
-            config_overrides["syndic_master"] = master_of_masters_config["interface"]
-            config_overrides["syndic_master_port"] = master_of_masters_config["ret_port"]
-
-        master_config = master.MasterFactory.default_config(
-            root_dir,
-            master_id=master_id,
-            default_options=default_options,
-            config_overrides=config_overrides,
-            order_masters=order_masters,
-        )
-        self.final_master_config_tweaks(master_config)
-        master_config = self.pytestconfig.hook.pytest_saltfactories_write_master_configuration(
-            request=request, master_config=master_config
-        )
-        self.pytestconfig.hook.pytest_saltfactories_verify_master_configuration(
-            request=request,
-            master_config=master_config,
-            username=SaltFactoriesManager.get_running_username(),
-        )
-        self.cache["configs"]["masters"][master_id] = master_config
-        request.addfinalizer(lambda: self.cache["configs"]["masters"].pop(master_id))
-        return master_config
-
-    def spawn_master(
-        self, request, master_id, order_masters=False, master_of_masters_id=None,
-    ):
-        """
-        Spawn a salt-master
-        """
-        if master_id in self.cache["masters"]:
-            raise RuntimeError("A master by the ID of '{}' was already spawned".format(master_id))
-
-        master_config = self.cache["configs"]["masters"].get(master_id)
-        if master_config is None:
-            master_config = self.configure_master(
+            minion_config = self.configure_minion(
                 request,
-                master_id,
-                order_masters=order_masters,
-                master_of_masters_id=master_of_masters_id,
+                minion_id,
+                master_id=master_id,
+                config_defaults=config_defaults,
+                config_overrides=config_overrides,
             )
 
         return self._start_daemon(
-            request, "salt-master", master_config, salt_factories.SaltMaster, "masters", master_id
+            request,
+            "salt-minion",
+            minion_config,
+            salt_factories.SaltMinion,
+            "minions",
+            minion_id,
+            max_start_attempts=max_start_attempts,
+            **extra_daemon_class_kwargs
         )
 
-    def configure_syndic(self, request, syndic_id, master_of_masters_id=None):
+    def configure_syndic(
+        self,
+        request,
+        syndic_id,
+        master_of_masters_id=None,
+        config_defaults=None,
+        config_overrides=None,
+    ):
         """
         Configure a salt-syndic.
 
         In order for the syndic to be reactive, it actually needs three(3) daemons running, `salt-master`,
         `salt-minion` and `salt-syndic`.
 
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            syndic_id(str):
+                The Syndic ID. This ID will be shared by the ``salt-master``, ``salt-minion`` and ``salt-syndic``
+                processes.
+            master_of_masters_id(str):
+                The master of masters ID that the master configured in this :ref:`Syndic <salt:syndic>` topology
+                scenario shall connect to.
+            config_defaults(dict):
+                A dictionary of default configurations with three top level keys, ``master``, ``minion`` and
+                ``syndic``, to use when configuring the  ``salt-master``, ``salt-minion`` and ``salt-syndic``
+                respectively.
+            config_overrides(dict):
+                A dictionary of configuration overrides with three top level keys, ``master``, ``minion`` and
+                ``syndic``, to use when configuring the  ``salt-master``, ``salt-minion`` and ``salt-syndic``
+                respectively.
+
+        Returns:
+            dict: The syndic configuring dictionary
         """
         if syndic_id in self.cache["configs"]["syndics"]:
             return self.cache["configs"]["syndics"][syndic_id]
@@ -370,38 +556,82 @@ class SaltFactoriesManager(object):
 
         syndic_master_port = master_of_masters_config["ret_port"]
 
-        root_dir = self._get_root_dir_for_daemon(syndic_id)
+        root_dir = self._get_root_dir_for_daemon(
+            syndic_id, config_defaults=config_defaults.get("syndic") if config_defaults else None
+        )
 
-        default_options = self.pytestconfig.hook.pytest_saltfactories_generate_default_syndic_configuration(
+        defaults_and_overrides_top_level_keys = {"master", "minion", "syndic"}
+
+        _config_defaults = self.pytestconfig.hook.pytest_saltfactories_syndic_configuration_defaults(
             request=request,
             factories_manager=self,
             root_dir=root_dir,
             syndic_id=syndic_id,
             syndic_master_port=syndic_master_port,
         )
+        if _config_defaults and not set(_config_defaults).issubset(
+            defaults_and_overrides_top_level_keys
+        ):
+            raise RuntimeError(
+                "The config defaults returned by pytest_saltfactories_syndic_configuration_defaults must "
+                "only contain 3 top level keys: {}".format(
+                    ", ".join(defaults_and_overrides_top_level_keys)
+                )
+            )
+        if config_defaults:
+            if not set(config_defaults).issubset(defaults_and_overrides_top_level_keys):
+                raise RuntimeError(
+                    "The config_defaults keyword argument must only contain 3 top level keys: {}".format(
+                        ", ".join(defaults_and_overrides_top_level_keys)
+                    )
+                )
+            if _config_defaults:
+                salt.utils.dictupdate.update(_config_defaults, config_defaults)
+            else:
+                _config_defaults = config_defaults.copy()
 
-        config_overrides = self.pytestconfig.hook.pytest_saltfactories_syndic_configuration_overrides(
+        _config_overrides = self.pytestconfig.hook.pytest_saltfactories_syndic_configuration_overrides(
             request=request,
             factories_manager=self,
             root_dir=root_dir,
             syndic_id=syndic_id,
-            default_options=default_options,
+            config_defaults=_config_defaults,
         )
+        if _config_overrides and not set(_config_overrides).issubset(
+            defaults_and_overrides_top_level_keys
+        ):
+            raise RuntimeError(
+                "The config overrides returned by pytest_saltfactories_syndic_configuration_overrides must "
+                "only contain 3 top level keys: {}".format(
+                    ", ".join(defaults_and_overrides_top_level_keys)
+                )
+            )
+        if config_overrides:
+            if not set(config_overrides).issubset(defaults_and_overrides_top_level_keys):
+                raise RuntimeError(
+                    "The config_overrides keyword argument must only contain 3 top level keys: {}".format(
+                        ", ".join(defaults_and_overrides_top_level_keys)
+                    )
+                )
+            if _config_overrides:
+                salt.utils.dictupdate.update(_config_overrides, config_overrides)
+            else:
+                _config_overrides = config_overrides.copy()
 
         syndic_setup_config = syndic.SyndicFactory.default_config(
             root_dir,
             syndic_id=syndic_id,
-            default_options=default_options,
-            config_overrides=config_overrides,
+            config_defaults=_config_defaults,
+            config_overrides=_config_overrides,
             syndic_master_port=syndic_master_port,
         )
 
         master_config = syndic_setup_config["master"]
         self.final_master_config_tweaks(master_config)
-        master_config = self.pytestconfig.hook.pytest_saltfactories_write_master_configuration(
+        master_config = self.pytestconfig.hook.pytest_saltfactories_master_write_configuration(
             request=request, master_config=master_config
         )
-        self.pytestconfig.hook.pytest_saltfactories_verify_master_configuration(
+        self.pytestconfig.hook.pytest_saltfactories_master_verify_configuration(
             request=request,
             master_config=master_config,
             username=SaltFactoriesManager.get_running_username(),
@@ -412,10 +642,10 @@ class SaltFactoriesManager(object):
 
         minion_config = syndic_setup_config["minion"]
         self.final_minion_config_tweaks(minion_config)
-        minion_config = self.pytestconfig.hook.pytest_saltfactories_write_minion_configuration(
+        minion_config = self.pytestconfig.hook.pytest_saltfactories_minion_write_configuration(
             request=request, minion_config=minion_config
         )
-        self.pytestconfig.hook.pytest_saltfactories_verify_minion_configuration(
+        self.pytestconfig.hook.pytest_saltfactories_minion_verify_configuration(
             request=request,
             minion_config=minion_config,
             username=SaltFactoriesManager.get_running_username(),
@@ -426,10 +656,10 @@ class SaltFactoriesManager(object):
 
         syndic_config = syndic_setup_config["syndic"]
         self.final_syndic_config_tweaks(syndic_config)
-        syndic_config = self.pytestconfig.hook.pytest_saltfactories_write_syndic_configuration(
+        syndic_config = self.pytestconfig.hook.pytest_saltfactories_syndic_write_configuration(
             request=request, syndic_config=syndic_config
         )
-        self.pytestconfig.hook.pytest_saltfactories_verify_syndic_configuration(
+        self.pytestconfig.hook.pytest_saltfactories_syndic_verify_configuration(
             request=request,
             syndic_config=syndic_config,
             username=SaltFactoriesManager.get_running_username(),
@@ -441,9 +671,44 @@ class SaltFactoriesManager(object):
         request.addfinalizer(lambda: self.cache["configs"]["syndics"].pop(syndic_id))
         return syndic_config
 
-    def spawn_syndic(self, request, syndic_id, master_of_masters_id=None):
+    def spawn_syndic(
+        self,
+        request,
+        syndic_id,
+        master_of_masters_id=None,
+        config_defaults=None,
+        config_overrides=None,
+        max_start_attempts=3,
+        **extra_daemon_class_kwargs
+    ):
         """
         Spawn a salt-syndic
+
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            syndic_id(str):
+                The Syndic ID. This ID will be shared by the ``salt-master``, ``salt-minion`` and ``salt-syndic``
+                processes.
+            master_of_masters_id(str):
+                The master of masters ID that the master configured in this :ref:`Syndic <salt:syndic>` topology
+                scenario shall connect to.
+            config_defaults(dict):
+                A dictionary of default configurations with three top level keys, ``master``, ``minion`` and
+                ``syndic``, to use when configuring the  ``salt-master``, ``salt-minion`` and ``salt-syndic``
+                respectively.
+            config_overrides(dict):
+                A dictionary of configuration overrides with three top level keys, ``master``, ``minion`` and
+                ``syndic``, to use when configuring the  ``salt-master``, ``salt-minion`` and ``salt-syndic``
+                respectively.
+            max_start_attempts(int):
+                How many attempts should be made to start the syndic in case of failure to validate that its running
+            extra_daemon_class_kwargs(dict):
+                Extra keyword arguments to pass to :py:class:`~saltfactories.utils.processes.salts.SaltSyndic`
+
+        Returns:
+            :py:class:`~saltfactories.utils.processes.salts.SaltSyndic`:
+                The syndic process class instance
         """
         if syndic_id in self.cache["syndics"]:
             raise RuntimeError("A syndic by the ID of '{}' was already spawned".format(syndic_id))
@@ -451,23 +716,55 @@ class SaltFactoriesManager(object):
         syndic_config = self.cache["configs"]["syndics"].get(syndic_id)
         if syndic_config is None:
             syndic_config = self.configure_syndic(
-                request, syndic_id, master_of_masters_id=master_of_masters_id
+                request,
+                syndic_id,
+                master_of_masters_id=master_of_masters_id,
+                config_defaults=config_defaults,
+                config_overrides=config_overrides,
             )
 
         # We need the syndic master and minion running
         if syndic_id not in self.cache["masters"]:
-            self.spawn_master(request, syndic_id)
+            self.spawn_master(
+                request, syndic_id, max_start_attempts=max_start_attempts,
+            )
 
         if syndic_id not in self.cache["minions"]:
-            self.spawn_minion(request, syndic_id)
+            self.spawn_minion(
+                request, syndic_id, max_start_attempts=max_start_attempts,
+            )
 
         return self._start_daemon(
-            request, "salt-syndic", syndic_config, salt_factories.SaltSyndic, "syndics", syndic_id
+            request,
+            "salt-syndic",
+            syndic_config,
+            salt_factories.SaltSyndic,
+            "syndics",
+            syndic_id,
+            max_start_attempts=max_start_attempts,
+            **extra_daemon_class_kwargs
         )
 
-    def configure_proxy_minion(self, request, proxy_minion_id, master_id=None):
+    def configure_proxy_minion(
+        self, request, proxy_minion_id, master_id=None, config_defaults=None, config_overrides=None
+    ):
         """
         Configure a salt-proxy
+
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            proxy_minion_id(str):
+                The proxy minion ID
+            master_id(str):
+                The master ID this minion will connect to.
+            config_defaults(dict):
+                A dictionary of default configuration to use when configuring the proxy minion
+            config_overrides(dict):
+                A dictionary of configuration overrides to use when configuring the proxy minion
+
+        Returns:
+            dict: The proxy minion configuration dictionary
         """
         if proxy_minion_id in self.cache["configs"]["proxy_minions"]:
             return self.cache["configs"]["proxy_minions"][proxy_minion_id]
@@ -477,34 +774,46 @@ class SaltFactoriesManager(object):
             master_config = self.cache["configs"]["masters"][master_id]
             master_port = master_config.get("ret_port")
 
-        root_dir = self._get_root_dir_for_daemon(proxy_minion_id)
+        root_dir = self._get_root_dir_for_daemon(proxy_minion_id, config_defaults=config_defaults)
 
-        default_options = self.pytestconfig.hook.pytest_saltfactories_generate_default_proxy_minion_configuration(
+        _config_defaults = self.pytestconfig.hook.pytest_saltfactories_proxy_minion_configuration_defaults(
             request=request,
             factories_manager=self,
             root_dir=root_dir,
             proxy_minion_id=proxy_minion_id,
             master_port=master_port,
         )
-        config_overrides = self.pytestconfig.hook.pytest_saltfactories_proxy_minion_configuration_overrides(
+        if config_defaults:
+            if _config_defaults:
+                salt.utils.dictupdate.update(_config_defaults, config_defaults)
+            else:
+                _config_defaults = config_defaults.copy()
+
+        _config_overrides = self.pytestconfig.hook.pytest_saltfactories_proxy_minion_configuration_overrides(
             request=request,
             factories_manager=self,
             root_dir=root_dir,
             proxy_minion_id=proxy_minion_id,
-            default_options=default_options,
+            config_defaults=_config_defaults,
         )
+        if config_overrides:
+            if _config_overrides:
+                salt.utils.dictupdate.update(_config_overrides, config_overrides)
+            else:
+                _config_overrides = config_overrides.copy()
+
         proxy_minion_config = proxy.ProxyMinionFactory.default_config(
             root_dir,
             proxy_minion_id=proxy_minion_id,
-            default_options=default_options,
-            config_overrides=config_overrides,
+            config_defaults=_config_defaults,
+            config_overrides=_config_overrides,
             master_port=master_port,
         )
         self.final_proxy_minion_config_tweaks(proxy_minion_config)
-        proxy_minion_config = self.pytestconfig.hook.pytest_saltfactories_write_proxy_minion_configuration(
+        proxy_minion_config = self.pytestconfig.hook.pytest_saltfactories_proxy_minion_write_configuration(
             request=request, proxy_minion_config=proxy_minion_config
         )
-        self.pytestconfig.hook.pytest_saltfactories_verify_proxy_minion_configuration(
+        self.pytestconfig.hook.pytest_saltfactories_proxy_minion_verify_configuration(
             request=request,
             proxy_minion_config=proxy_minion_config,
             username=SaltFactoriesManager.get_running_username(),
@@ -520,9 +829,39 @@ class SaltFactoriesManager(object):
         request.addfinalizer(lambda: self.cache["configs"]["proxy_minions"].pop(proxy_minion_id))
         return proxy_minion_config
 
-    def spawn_proxy_minion(self, request, proxy_minion_id, master_id=None):
+    def spawn_proxy_minion(
+        self,
+        request,
+        proxy_minion_id,
+        master_id=None,
+        config_defaults=None,
+        config_overrides=None,
+        max_start_attempts=3,
+        **extra_daemon_class_kwargs
+    ):
         """
         Spawn a salt-proxy
+
+        Args:
+            request(:fixture:`request`):
+                The PyTest test execution request
+            proxy_minion_id(str):
+                The proxy minion ID
+            master_id(str):
+                The master ID this minion will connect to.
+            config_defaults(dict):
+                A dictionary of default configuration to use when configuring the proxy minion
+            config_overrides(dict):
+                A dictionary of configuration overrides to use when configuring the proxy minion
+            max_start_attempts(int):
+                How many attempts should be made to start the proxy minion in case of failure to validate that
+                its running
+            extra_daemon_class_kwargs(dict):
+                Extra keyword arguments to pass to :py:class:`~saltfactories.utils.processes.salts.SaltProxyMinion`
+
+        Returns:
+            :py:class:`~saltfactories.utils.processes.salts.SaltProxyMinion`:
+                The proxy minion process class instance
         """
         if proxy_minion_id in self.cache["proxy_minions"]:
             raise RuntimeError(
@@ -532,7 +871,11 @@ class SaltFactoriesManager(object):
         proxy_minion_config = self.cache["configs"]["proxy_minions"].get(proxy_minion_id)
         if proxy_minion_config is None:
             proxy_minion_config = self.configure_proxy_minion(
-                request, proxy_minion_id, master_id=master_id
+                request,
+                proxy_minion_id,
+                master_id=master_id,
+                config_defaults=config_defaults,
+                config_overrides=config_overrides,
             )
 
         return self._start_daemon(
@@ -542,6 +885,8 @@ class SaltFactoriesManager(object):
             salt_factories.SaltProxyMinion,
             "proxy_minions",
             proxy_minion_id,
+            max_start_attempts=max_start_attempts,
+            **extra_daemon_class_kwargs
         )
 
     def get_salt_cli(self, request, master_id, **cli_kwargs):
@@ -646,6 +991,7 @@ class SaltFactoriesManager(object):
         environ=None,
         cwd=None,
         slow_stop=None,
+        max_start_attempts=3,
         **extra_daemon_class_kwargs
     ):
         """
@@ -664,7 +1010,7 @@ class SaltFactoriesManager(object):
             slow_stop=slow_stop,
             environ=environ,
             cwd=cwd,
-            max_attempts=3,
+            max_attempts=max_start_attempts,
             **extra_daemon_class_kwargs
         )
         self.cache["daemons"][daemon_id] = proc
@@ -675,7 +1021,14 @@ class SaltFactoriesManager(object):
         return proc
 
     def _start_daemon(
-        self, request, script_name, daemon_config, daemon_class, cache_key, daemon_id
+        self,
+        request,
+        script_name,
+        daemon_config,
+        daemon_class,
+        cache_key,
+        daemon_id,
+        max_start_attempts=3,
     ):
         """
         Helper method to start daemons
@@ -696,7 +1049,7 @@ class SaltFactoriesManager(object):
             slow_stop=self.slow_stop,
             environ=self.environ,
             cwd=self.cwd,
-            max_attempts=3,
+            max_attempts=max_start_attempts,
             event_listener=self.event_listener,
         )
         self.cache[cache_key][daemon_id] = proc
@@ -706,7 +1059,9 @@ class SaltFactoriesManager(object):
         request.addfinalizer(lambda: self.cache[cache_key].pop(daemon_id))
         return proc
 
-    def _get_root_dir_for_daemon(self, daemon_id):
+    def _get_root_dir_for_daemon(self, daemon_id, config_defaults=None):
+        if config_defaults and "root_dir" in config_defaults:
+            return py.path.local(config_defaults["root_dir"]).ensure(dir=True)
         counter = 1
         root_dir = self.root_dir.join(daemon_id)
         while True:
