@@ -25,19 +25,16 @@ from saltfactories.utils import ports
 class MinionFactory(object):
     @staticmethod
     def default_config(
-        root_dir, minion_id, default_options=None, config_overrides=None, master_port=None
+        root_dir, minion_id, config_defaults=None, config_overrides=None, master_port=None
     ):
-        if default_options is None:
-            default_options = salt.config.DEFAULT_MINION_OPTS.copy()
+        if config_defaults is None:
+            config_defaults = salt.config.DEFAULT_MINION_OPTS.copy()
+            config_defaults.pop("user", None)
 
         conf_dir = root_dir.join("conf").ensure(dir=True)
         conf_file = conf_dir.join("minion").strpath
 
-        stop_sending_events_file = conf_dir.join("stop-sending-events-{}".format(minion_id)).strpath
-        with salt.utils.files.fopen(stop_sending_events_file, "w") as wfh:
-            wfh.write("")
-
-        _default_options = {
+        _config_defaults = {
             "id": minion_id,
             "conf_file": conf_file,
             "root_dir": root_dir.strpath,
@@ -61,11 +58,11 @@ class MinionFactory(object):
             "transport": "zeromq",
             "pytest-minion": {"log": {"prefix": "salt-minion({})".format(minion_id)},},
         }
-        # Merge in the initial default options with the internal _default_options
-        salt.utils.dictupdate.update(default_options, _default_options, merge_lists=True)
+        # Merge in the initial default options with the internal _config_defaults
+        salt.utils.dictupdate.update(config_defaults, _config_defaults, merge_lists=True)
 
         if config_overrides:
             # Merge in the default options with the minion_config_overrides
-            salt.utils.dictupdate.update(default_options, config_overrides, merge_lists=True)
+            salt.utils.dictupdate.update(config_defaults, config_overrides, merge_lists=True)
 
-        return default_options
+        return config_defaults
