@@ -13,7 +13,7 @@ import pytest
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_generate_default_minion_configuration(
+def pytest_saltfactories_minion_configuration_defaults(
     request, factories_manager, root_dir, minion_id, master_port
 ):
     """
@@ -25,31 +25,31 @@ def pytest_saltfactories_generate_default_minion_configuration(
 
 @pytest.hookspec(firstresult=True)
 def pytest_saltfactories_minion_configuration_overrides(
-    request, factories_manager, root_dir, minion_id, default_options
+    request, factories_manager, root_dir, minion_id, config_defaults
 ):
     """
     Hook which should return a dictionary tailored for the provided minion_id.
-    This dictionary will override the default_options dictionary.
+    This dictionary will override the config_defaults dictionary.
 
     Stops at the first non None result
     """
 
 
-def pytest_saltfactories_verify_minion_configuration(request, minion_config, username):
+def pytest_saltfactories_minion_verify_configuration(request, minion_config, username):
     """
     This hook is called to vefiry the provided minion configuration
     """
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_write_minion_configuration(request, minion_config):
+def pytest_saltfactories_minion_write_configuration(request, minion_config):
     """
     This hook is called to write the provided minion configuration
     """
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_generate_default_master_configuration(
+def pytest_saltfactories_master_configuration_defaults(
     request, factories_manager, root_dir, master_id, order_masters
 ):
     """
@@ -61,31 +61,31 @@ def pytest_saltfactories_generate_default_master_configuration(
 
 @pytest.hookspec(firstresult=True)
 def pytest_saltfactories_master_configuration_overrides(
-    request, factories_manager, root_dir, master_id, default_options, order_masters
+    request, factories_manager, root_dir, master_id, config_defaults, order_masters
 ):
     """
     Hook which should return a dictionary tailored for the provided master_id.
-    This dictionary will override the default_options dictionary.
+    This dictionary will override the config_defaults dictionary.
 
     Stops at the first non None result
     """
 
 
-def pytest_saltfactories_verify_master_configuration(request, master_config, username):
+def pytest_saltfactories_master_verify_configuration(request, master_config, username):
     """
     This hook is called to vefiry the provided master configuration
     """
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_write_master_configuration(request, master_config):
+def pytest_saltfactories_master_write_configuration(request, master_config):
     """
     This hook is called to write the provided master configuration
     """
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_generate_default_syndic_configuration(
+def pytest_saltfactories_syndic_configuration_defaults(
     request, factories_manager, root_dir, syndic_id, syndic_master_port
 ):
     """
@@ -101,11 +101,11 @@ def pytest_saltfactories_generate_default_syndic_configuration(
 
 @pytest.hookspec(firstresult=True)
 def pytest_saltfactories_syndic_configuration_overrides(
-    request, factories_manager, root_dir, syndic_id, default_options
+    request, factories_manager, root_dir, syndic_id, config_defaults
 ):
     """
     Hook which should return a dictionary tailored for the provided syndic_id.
-    This dictionary will override the default_options dictionary.
+    This dictionary will override the config_defaults dictionary.
 
     The returned dictionary should contain 3 keys:
 
@@ -113,28 +113,28 @@ def pytest_saltfactories_syndic_configuration_overrides(
     * `minion`: The config overrides for the master running along with the syndic
     * `syndic`: The config overridess for the master running along with the syndic
 
-    The `default_options` parameter be None or have 3 keys, `master`, `minion`, `syndic`,
+    The `config_defaults` parameter be None or have 3 keys, `master`, `minion`, `syndic`,
     while will contain the default options for each of the daemons.
 
     Stops at the first non None result
     """
 
 
-def pytest_saltfactories_verify_syndic_configuration(request, syndic_config, username):
+def pytest_saltfactories_syndic_verify_configuration(request, syndic_config, username):
     """
     This hook is called to vefiry the provided syndic configuration
     """
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_write_syndic_configuration(request, syndic_config):
+def pytest_saltfactories_syndic_write_configuration(request, syndic_config):
     """
     This hook is called to write the provided syndic configuration
     """
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_generate_default_proxy_minion_configuration(
+def pytest_saltfactories_proxy_minion_configuration_defaults(
     request, factories_manager, root_dir, proxy_minion_id, master_port
 ):
     """
@@ -146,24 +146,24 @@ def pytest_saltfactories_generate_default_proxy_minion_configuration(
 
 @pytest.hookspec(firstresult=True)
 def pytest_saltfactories_proxy_minion_configuration_overrides(
-    request, factories_manager, root_dir, proxy_minion_id, default_options
+    request, factories_manager, root_dir, proxy_minion_id, config_defaults
 ):
     """
     Hook which should return a dictionary tailored for the provided proxy_minion_id.
-    This dictionary will override the default_options dictionary.
+    This dictionary will override the config_defaults dictionary.
 
     Stops at the first non None result
     """
 
 
-def pytest_saltfactories_verify_proxy_minion_configuration(request, proxy_minion_config, username):
+def pytest_saltfactories_proxy_minion_verify_configuration(request, proxy_minion_config, username):
     """
     This hook is called to vefiry the provided proxy_minion configuration
     """
 
 
 @pytest.hookspec(firstresult=True)
-def pytest_saltfactories_write_proxy_minion_configuration(request, proxy_minion_config):
+def pytest_saltfactories_proxy_minion_write_configuration(request, proxy_minion_config):
     """
     This hook is called to write the provided proxy_minion configuration
     """
